@@ -1,7 +1,5 @@
-from F import DICT
-from F import LIST
+from F import DICT, LIST
 from F.LOG import Log
-from FCM import MCServers
 from FCM.MCCore import MCCore
 from FCM.Jarticle import JQ, F
 from FCM.FQ import Q
@@ -17,24 +15,14 @@ Usage:
 
 Log = Log("jArticles")
 
-ARTICLES_COLLECTION = "articles"
+COLLECTION_NAME = "articles"
 
 """ Master Class to work with Article Collection """
 class jArticles(MCCore):
 
-    def constructor_jarticles_with_host(self, dbUri=None, dbName=None):
-        try:
-            if not dbUri:
-                dbUri = MCServers.MONGO_DATABASE_URI
-                dbName = MCServers.db_name
-            # MCDB.GET_SET_CUSTOM_HOST(dbUri, dbName, ARTICLES_COLLECTION)
-            self.constructor(dbUri, dbName)
-            self.set_ccollection(ARTICLES_COLLECTION)
-            self.mcollection = self.core_collection
-            return self
-        except Exception as e:
-            Log.e("Failed to Connect to DB.", error=e)
-            return False
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self.connect(COLLECTION_NAME)
 
     def article_url_exists(self, potentialUrl):
         url_query = Q.BASE(F.URL, potentialUrl)
