@@ -1,5 +1,5 @@
-import time
-from F import LIST
+# import time
+from F import LIST, DICT
 from F.LOG import Log
 Log = Log("MCollection")
 
@@ -50,6 +50,13 @@ class MCCollection:
         if results and len(results) > 0:
             return results
         return False
+    def get_field_names(self):
+        fields = []
+        oneResult = self.base_query({}, 0, 1)
+        oneDoc = LIST.get(0, oneResult)
+        for doc in oneDoc:
+            fields.append(doc)
+        return fields
 
     @staticmethod
     def to_list(cursor):
@@ -63,6 +70,14 @@ class MCCollection:
         Log.v("Object Does Not Exist in Database.")
         return False
 
+    def record_exists_by_field_match(self, field, value) -> bool:
+        temp = self.base_query({field:value})
+        if temp:
+            Log.w("Object Exists in Database Already. Skipping...")
+            return True
+        Log.v("Object Does Not Exist in Database.")
+        return False
+
     def add_records(self, list_of_objects):
         """ Each Object should be JSON Format """
         list_of_objects = LIST.flatten(list_of_objects)
@@ -73,9 +88,20 @@ class MCCollection:
                 self.insert_record(objectItem)
         Log.w(f"Finished Add Records Queue.")
 
+    def add_records_field_match(self, list_of_objects, fieldName):
+        """ Each Object should be JSON Format """
+        list_of_objects = LIST.flatten(list_of_objects)
+        Log.w(f"Beginning Add Records Queue. COUNT=[ {len(list_of_objects)} ]")
+        for objectItem in list_of_objects:
+            fieldValue = DICT.get(fieldName, objectItem, default=False)
+            article_exists = self.record_exists_by_field_match(fieldName, fieldValue)
+            if not article_exists:
+                self.insert_record(objectItem)
+        Log.w(f"Finished Add Records Queue.")
+
     def insert_record(self, kwargs):
         try:
-            time.sleep(1)
+            # time.sleep(1)
             self.mcollection.insert_one(kwargs)
             Log.s(f"NEW Record created in DB=[ {self.mcollection_name} ]")
             return True
@@ -85,7 +111,7 @@ class MCCollection:
 
     def update_record(self, findQuery: dict, updateQuery: dict, upsert=True):
         try:
-            time.sleep(1)
+            # time.sleep(1)
             self.mcollection.update_one( findQuery, { "$set": updateQuery }, upsert=upsert )
             Log.s(f"UPDATED Record in DB=[ {self.mcollection_name} ]")
             return True
@@ -105,7 +131,7 @@ class MCCollection:
 
     def update_many_records(self, findQuery: dict, updateQueries: list, upsert=True):
         try:
-            time.sleep(1)
+            # time.sleep(1)
             self.mcollection.update_many( findQuery, updateQueries, upsert=upsert )
             Log.s(f"UPDATED Record in DB=[ {self.mcollection_name} ]")
             return True
@@ -115,17 +141,10 @@ class MCCollection:
 
     def remove_record(self, kwargs):
         try:
-            time.sleep(1)
+            # time.sleep(1)
             self.mcollection.delete_one(kwargs)
             Log.s(f"Removed Record in DB=[ {self.mcollection_name} ]")
             return True
         except Exception as e:
             Log.e(f"Failed to remove record in DB=[ {self.mcollection_name} ]", error=e)
             return False
-
-
-# if __name__ == '__main__':
-    # n = MCollection.construct_manual_collection(collectionName="test", hostName=MServers.PROD, databaseName="research")
-    # n.add_records({"date": "Today", "BTC": 26.76})
-    # temp = n.get_document_count()
-    # print(temp)
\ No newline at end of file
